Learn R Programming

m2b (version 1.1.0)

ltraj2xytb: ltraj object conversion to xytb object

Description

The function converts a ltraj object to a xytb object (see https://CRAN.R-project.org/package=adehabitatLT and xytb-class).

Usage

ltraj2xytb(ltraj, desc = "ltraj object convert to xytb")

Value

A xytb object with behavioural information taken from the infolocs (aka ltraj object should correspond the an export of xytb object in ltraj).

Arguments

ltraj

A ltraj object

desc

General descriptor of the data

Author

Laurent Dubroca

Examples

Run this code
if (FALSE) { 
#track_CAGA_005 is a dataset
xytb<-xytb(track_CAGA_005,"a track",3,.5)
ltraj<-xytb2ltraj(xytb)
xytb2<-ltraj2xytb(ltraj,"a track")
}

Run the code above in your browser using DataLab