Learn R Programming

m2b (version 1.1.0)

xytb-class: xytb class definition

Description

xytb is a trajectory object with observed behaviour

Arguments

Slots

desc

a character vector. A description of the data.

xyt

a data frame of the track information. One row is one position described by 11 variables :

id:individual id
t:time in POSIXct
x:longitude
y:latitude
dt:time (s) between the current location and the next one
dist:distance (m) between the current location and the next one calculated using the Vincenty ellipsoid method. See distVincentyEllipsoid)
v:speed (m.s^-1)
dx:the increase of the move in the x direction.
dy:the increase of the move in the y direction.
theta:the angle between each move and the x axis.
thetarel:the turning angle between successive moves.

This slot is very similar to the ltraj class of the adehabitatLT package.

b

a data frame of the observed behaviour related to the track. One row is one behavioural observation related to the track described by 3 variables:

id:individual id
t:time in POSIXct
b:observed behaviour (character)

dxyt

a data frame of the derived variables from the track.

befdxyt

a data frame of the derived variables shifted back in time.

model

a randomForest model (see randomForest).

rfcv

the output of the cross-validation procedure (see rfcv).

predb

a data frame of the predicted behaviour using the random forest model of the slot model. 3 variables :

id:individual id
t:time in POSIXct
b:observed behaviour (character)

Author

Laurent Dubroca