Learn R Programming

m2b (version 1.1.0)

xytb2hmm: xytb object conversion to moveHMM object

Description

The function converts a xytb object to a moveHMM dataframe (see https://CRAN.R-project.org/package=moveHMM and prepData).

Usage

xytb2hmm(xytb)

Value

A dataframe ready to be used by the function of the `moveHMM`

Arguments

xytb

A xytb object

Author

Laurent Dubroca

Examples

Run this code
#track_CAGA_005 is a dataset
xytb<-xytb(track_CAGA_005,"a track",3,.5)
xyhmm <-xytb2hmm(xytb)
#then you can use moveHMM functions
if(requireNamespace("moveHMM")){
	plot(xyhmm)
}

Run the code above in your browser using DataLab