Learn R Programming

m2b (version 1.1.0)

xytb2ltraj: xytb class conversion to ltraj object

Description

The function converts a xytb object to a ltraj object as defined in the adehabitatLT package (see https://CRAN.R-project.org/package=adehabitatLT as.ltraj).

Usage

xytb2ltraj(xytb)

Value

A ltraj object with behavioural information recorded in the infoloc

Arguments

xytb

An xytb object

Author

Laurent Dubroca

Examples

Run this code
#track_CAGA_005 is a dataset
xytb<-xytb(track_CAGA_005,"a track",3,.5)
ltraj<-xytb2ltraj(xytb)
#all adehabitatLT function are now available
summary(ltraj)
plot(ltraj)

Run the code above in your browser using DataLab