powered by
The function converts a ltraj object to a xytb object (see https://CRAN.R-project.org/package=adehabitatLT and xytb-class).
ltraj2xytb(ltraj, desc = "ltraj object convert to xytb")
A xytb object with behavioural information taken from the infolocs (aka ltraj object should correspond the an export of xytb object in ltraj).
A ltraj object
General descriptor of the data
Laurent Dubroca
if (FALSE) { #track_CAGA_005 is a dataset xytb<-xytb(track_CAGA_005,"a track",3,.5) ltraj<-xytb2ltraj(xytb) xytb2<-ltraj2xytb(ltraj,"a track") }
Run the code above in your browser using DataLab