powered by
The function converts a xytb object to a moveHMM dataframe (see https://CRAN.R-project.org/package=moveHMM and prepData).
xytb2hmm(xytb)
A dataframe ready to be used by the function of the `moveHMM`
A xytb object
Laurent Dubroca
#track_CAGA_005 is a dataset xytb<-xytb(track_CAGA_005,"a track",3,.5) xyhmm <-xytb2hmm(xytb) #then you can use moveHMM functions if(requireNamespace("moveHMM")){ plot(xyhmm) }
Run the code above in your browser using DataLab