powered by
The function converts a xytb object to a ltraj object as defined in the adehabitatLT package (see https://CRAN.R-project.org/package=adehabitatLT as.ltraj).
xytb2ltraj(xytb)
A ltraj object with behavioural information recorded in the infoloc
An xytb object
Laurent Dubroca
#track_CAGA_005 is a dataset xytb<-xytb(track_CAGA_005,"a track",3,.5) ltraj<-xytb2ltraj(xytb) #all adehabitatLT function are now available summary(ltraj) plot(ltraj)
Run the code above in your browser using DataLab